@@ -386,12 +386,13 @@ ephy_adblock_extension_edit_cb (GtkAction *action, EphyWindow *window)
 
 static void
 switch_page_cb (GtkNotebook *notebook,
-		GtkNotebookPage *page,
+		GtkWidget *page,
 		guint page_num,
 		EphyWindow *window)
 {
 	/* FIXME: this shouldn't happen anymore with gtk 2.10 ! Test & remove */
-	if (gtk_widget_get_realized (window) == FALSE) return; /* on startup */
+	if (gtk_widget_get_realized (GTK_WIDGET (window)) == FALSE)
+		return; /* on startup */
 
 	update_statusbar (window);
 }
