@@ -315,7 +315,7 @@ load_status_cb (EphyEmbed *embed,
 
 static void
 switch_page_cb (GtkNotebook *notebook,
-		GtkNotebookPage *page,
+		GtkWidget *page,
 		guint page_num,
 		EphyWindow *window)
 {
